Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CurrencyPair ¶
CurrencyPair represents a pair of trading currency
func (*CurrencyPair) String ¶
func (p *CurrencyPair) String() string
String returns a unique string based on the given pair
type IParsableTicker ¶
type IParsableTicker interface {
Coins() ([]*CurrencyPair, error)
Tickers() ([]*Ticker, error)
}
IParsableTicker represents a object that can parse and return Ticker
type IParser ¶
type IParser interface {
// Coins returns an array of supported cryptocurrencies
RawTicker() (IParsableTicker, error)
}
IParser represents a object that can parse and return a IParsableTicker
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
Parser represents a Crypto Client
func NewParser ¶
func NewParser(p TickerType) *Parser
NewParser returns a new Crypto Client with specific market
func (*Parser) Parse ¶
func (p *Parser) Parse() (IParsableTicker, error)
Parse tries to fetch and parse ticker data from the market, and returns IParsableTicker
type Ticker ¶
type Ticker struct {
Currency *CurrencyPair
Volume string
Last string
High string
Low string
First string
}
Ticker represents a Ticker
type TickerType ¶
type TickerType int
TickerType represents makerts
const ( CoinoneTicker TickerType = 1 << iota // Coinone BithumbTicker // Bithumb PoloniexTicker // Poloniex BittrexTicker // Bittrex BitfinexTicker // Bitfinex )
Click to show internal directories.
Click to hide internal directories.